@@ -5,13 +5,18 @@
 #' @export
 installJuliaPackages <- function(){
   
-  strings1 <- c('"https://github.com/manuhuth/Coconots.jl"')
-  strings2 <- c("https://github.com/manuhuth/Coconots.jl")
+  strings1 <- c('"Coconots"')
+  strings2 <- c('Pkg.add("Coconots")')
   for (i in 1:length(strings1)){
     if (!JuliaConnectoR::juliaEval(paste0(strings1[i], ' in keys(Pkg.project().dependencies)'))){
       #JuliaConnectoR.utils::install_julia_packages(strings2[i])
       JuliaConnectoR::juliaEval("using Pkg")
-      JuliaConnectoR::juliaEval(paste0('Pkg.add(url ="', strings2[i], '")') )
+      JuliaConnectoR::juliaEval(paste0(strings2[i]) )
     }
   }
-}
\ No newline at end of file
+  JuliaConnectoR::juliaEval('
+      using Coconots
+      using Random
+    ')
+}
+
